run_deterministic_comparison_iran: Specific deterministic model run for Iran with timing of...

View source: R/mcmc_utils.R

run_deterministic_comparison_iranR Documentation

Specific deterministic model run for Iran with timing of Delta included

Description

Specific deterministic model run for Iran with timing of Delta included

Usage

run_deterministic_comparison_iran(
  data,
  squire_model,
  model_params,
  model_start_date = "2020-02-02",
  obs_params = list(phi_cases = 0.1, k_cases = 2, phi_death = 1, k_death = 2, exp_noise
    = 1e+06),
  forecast_days = 0,
  save_history = FALSE,
  return = "ll"
)

Arguments

data

to fit to.

squire_model

A squire model to use

model_params

Squire model parameters. Created from a call to one of the parameters_<type>_model functions.

model_start_date

Date to run model simulations from

obs_params

List of parameters used for comparing model to data

forecast_days

Days ahead to include in output

save_history

Whether to save full history. Default = FALSE

return

Set return depending on what is needed. 'full' and "sample" gives the entire output, 'll' gives the log-likelihood


OJWatson/iran-ascertainment documentation built on April 24, 2022, 10:09 p.m.